@@ -9,3 +9,8 @@ def setup(app):
         "zzzeeksphinx", path.join(package_dir, "themes", "zzzeeksphinx")
     )
     app.add_html_theme("zsmako", path.join(package_dir, "themes", "zsmako"))
+
+    return {
+        "parallel_read_safe": True,
+        "parallel_write_safe": True,
+    }
